@model IEnumerable<Example_Portal.Certificates>

@{
    ViewBag.Title = "Index"; 
}

@helper ToolbarTemplate()
{
    <button class="k-button k-grid-excel"><span class="k-icon k-i-excel"></span>Export to Excel</button>
    <a class="k-button savesetting" href="/"><span></span>Save Settings</a>
    <a class="k-button loadsetting" href="/"><span></span>Load Settings</a>
}

@helper HeaderTemplate()
{
    <span>Common name</span>
}

<script type="text/x-kendo-template" id="toolbarTemplate">
    @Html.Raw(@ToolbarTemplate().ToHtmlString().Replace("#", "\\#").Replace("</scr", "<\\/scr"))
</script>

<script type="text/x-kendo-template" id="headerTemplate">
    @Html.Raw(@HeaderTemplate().ToHtmlString().Replace("#", "\\#").Replace("</scr", "<\\/scr"))
</script>

@(Html.Kendo().Grid<Example_Portal.Certificates>()
    .Name("grid")
    .Columns(columns =>
    {
        columns.Bound(c => c.Certificate).Width(200);        
        columns.Bound(p => p.SerialNumber).ClientTemplate("<p class='text-center'><i class='k-icon k-i-information'></i></p>").Width(5).Title("Ser. nr.");
        columns.Bound(p => p.Thumbprint).Hidden();       
        columns.Bound(p => p.Id).ClientTemplate("" +
        "<table>"+
            "<tbody>"+
                "<tr>"+
                    "<td><a href='" + @Url.Action("Details", "Certificates", new { id = "#=Id#" }) + "' '><i class='k-icon k-i-detail-section'></i></a></td>" +
                    "<td><a href='" + @Url.Action("Delete", "Certificates", new { id = "#=Id#" }) + "' '><i class='k-icon k-i-delete'></i></a> </td>" +
                "</tr>"+

            "</tbody>"+
        "</table>").Width(90).Title("");
    })
    /*
    .ToolBar(toolbar => {
        toolbar.Excel();
        toolbar.Save();
    })
    */
        .ToolBar(toolbar =>
        {
        toolbar.Template(@<text>@ToolbarTemplate()</text>);
    })

    .Editable(editable => editable.Mode(GridEditMode.InCell))
    .Pageable(x => x.PageSizes(new List<object> { 10, 25, 50, 100, "all" }).Refresh(true))
    .ColumnMenu()
    .Sortable()
    .Resizable(rsb => rsb.Columns(true))
    .Filterable()
    .HtmlAttributes(new { style = "width:1400px;" })    
    .Groupable()
    .DataSource(dataSource => dataSource

    .Ajax()
    .Batch(true)

    .Read(read => read.Action("Certificates_Read", "Certificates"))
    .Update(update => update.Action("EditCell_Update", "Certificates"))
      .Create(create => create.Action("Create", "Certificates"))
    .Model(model => {

        model.Id(p => p.Id);
        model.Field(p => p.Certificate).Editable(false);
        model.Field(p => p.Id).Editable(false);
       
        model.Field(p => p.SerialNumber).Editable(false);
        model.Field(p => p.Thumbprint).Editable(false);      

    }
    )
    )

    )

@(Html.Kendo().Tooltip()
    .For("#grid")    
    .Filter("td:nth-child(8)")
    .ContentHandler("toolTipContent")
    .Position(TooltipPosition.Center)
    .AutoHide(true)
)

<script>
    function toolTipContent(e) {
        var dataItem = $("#grid").data("kendoGrid").dataItem(e.target.closest("tr"));
        var content = dataItem.SerialNumber;
        return content;
    }
</script>

<script>
    $("#grid").on("click", ".savesetting", function (e) {
        var grid = $(this).closest("[data-role=grid]").data("kendoGrid");
        e.preventDefault();
        localStorage["settings"] = kendo.stringify(grid.getOptions());
    });

    $("#grid").on("click", ".loadsetting", function (e) {
        var grid = $(this).closest("[data-role=grid]").data("kendoGrid");
        e.preventDefault();
        var options = localStorage["settings"];
        if (options) {
            var parsedOptions = JSON.parse(options);
            parsedOptions.toolbar = [
                { template: $("#toolbarTemplate").html() }
            ];
            parsedOptions.columns[0].headerTemplate = $("#headerTemplate").html();
            grid.setOptions(parsedOptions);
        }
    });
</script>

